
:mod:`pyrcel.aerosol`.AerosolSpecies
===========================================

.. currentmodule:: pyrcel.aerosol

.. autoclass:: AerosolSpecies
   :members:
   :undoc-members:

   
   .. automethod:: __init__
   
